Nox - Flexible test automation for Python
=========================================

``nox`` is a command-line tool that automates testing in multiple Python
environments, similar to `tox`_. Unlike tox, Nox uses a standard Python
file for configuration.

The latest documentation is available on `Read the Docs`_.

The source code is available on `GitHub`_.

Python 2 Version
================

This is a custom version of nox which supports python 2.
It was created for a specific project's needs, `salt`_, because on some distributions where it's tested
there's either no Python 3 support or not a recent enough version of Python 3.

.. _salt: https://github.com/saltstack/salt
.. _tox: https://tox.readthedocs.io
.. _Read the Docs: https://nox.readthedocs.io
.. _GitHub: https://github.com/theacodes/nox
